.. IBP-Model documentation master file, created by
   sphinx-quickstart on Thu Nov 17 09:05:04 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst
   :end-before: inclusion-marker-install

Contents
--------

.. toctree::   
   :maxdepth: 2
   
   installation
   usage
   modules
   reference
   changelog



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
